@@ -2,12 +2,12 @@ use strict;
 use warnings;
 package Wing::Client;
 {
-  $Wing::Client::VERSION = '0.0200';
+  $Wing::Client::VERSION = '0.0300';
 }
 
 use HTTP::Thin;
 use HTTP::Request::Common;
-use HTTP::CookieJar::LWP;
+use HTTP::CookieJar;
 use JSON;
 use URI;
 use Ouch;
@@ -20,7 +20,7 @@ Wing::Client - A simple client to Wing's web services.
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -89,7 +89,7 @@ has agent => (
 );
 
 sub _build_agent {
-    return HTTP::Thin->new( cookie_jar => HTTP::CookieJar::LWP->new(), );
+    return HTTP::Thin->new( cookie_jar => HTTP::CookieJar->new(), );
 }
 
 =head2 get(path, params)
@@ -114,7 +114,7 @@ sub get {
     my ($self, $path, $params) = @_;
     my $uri = $self->_create_uri($path);
     $uri->query_form($params);
-    return $self->_process_request( GET $uri->as_string );
+    return $self->_process_request( GET $uri );
 }
 
 =head2 delete(path, params)
@@ -138,7 +138,7 @@ A hash reference of parameters you wish to pass to the web service.
 sub delete {
     my ($self, $path, $params) = @_;
     my $uri = $self->_create_uri($path);
-    return $self->_process_request( POST $uri->as_string, 'X-HTTP-Method' => 'DELETE', Content_Type => 'form-data', Content => $params );
+    return $self->_process_request(POST $uri->as_string, $params, 'X-HTTP-Method' => 'DELETE', Content_Type => 'form-data', Content => $params );
 }
 
 =head2 put(path, params)
@@ -162,7 +162,8 @@ A hash reference of parameters you wish to pass to the web service.
 sub put {
     my ($self, $path, $params) = @_;
     my $uri = $self->_create_uri($path);
-    return $self->_process_request( POST $uri->as_string, 'X-HTTP-Method' => 'PUT', Content_Type => 'form-data', Content => $params );
+    my $request = POST $uri->as_string, 'X-HTTP-Method' => 'PUT', Content_Type => 'form-data', Content => $params ;
+    return $self->_process_request($request);
 }
 
 =head2 post(path, params)
@@ -223,7 +224,7 @@ sub _process_response {
 L<HTTP::Thin>
 L<Ouch>
 L<HTTP::Request::Common>
-L<HTTP::CookieJar::LWP>
+L<HTTP::CookieJar>
 L<JSON>
 L<URI>
 L<Moo>
